@@ -7,7 +7,7 @@
 #  @classhierarchy
 #
 #  An RspDirective is an @see "RspConstruct" that represents an
-#  RSP preprocesing directive of format \code{<\%@ ... \%>}.
+#  RSP preprocessing directive of format \code{<\%@ ... \%>}.
 #  The directive is independent of the underlying programming language.
 # }
 #
@@ -27,7 +27,7 @@
 # @keyword internal
 #*/###########################################################################
 setConstructorS3("RspDirective", function(value=character(), ...) {
-  extend(RspConstruct(value, ...), "RspDirective");
+  extend(RspConstruct(value, ...), "RspDirective")
 })
 
 
@@ -59,97 +59,97 @@ setConstructorS3("RspDirective", function(value=character(), ...) {
 #*/#########################################################################
 setMethodS3("requireAttributes", "RspDirective", function(this, names, condition=c("all", "any"), ...) {
   # Argument 'condition':
-  condition <- match.arg(condition);
+  condition <- match.arg(condition)
 
-  attrs <- getAttributes(this);
-  ok <- is.element(names, names(attrs));
+  attrs <- getAttributes(this)
+  ok <- is.element(names, names(attrs))
 
   if (condition == "all") {
     if (!all(ok)) {
-      throw(RspPreprocessingException(sprintf("One or more required attributes (%s) are missing", paste(sQuote(names[!ok]), collapse=", ")), item=this));
+      throw(RspPreprocessingException(sprintf("One or more required attributes (%s) are missing", paste(sQuote(names[!ok]), collapse=", ")), item=this))
     }
   } else if (condition == "any") {
     if (!any(ok)) {
-      throw(RspPreprocessingException(sprintf("At least one of the required attributes (%s) must be given",  paste(sQuote(names[!ok]), collapse=", ")), item=this));
+      throw(RspPreprocessingException(sprintf("At least one of the required attributes (%s) must be given",  paste(sQuote(names[!ok]), collapse=", ")), item=this))
     }
   }
 
-  invisible(this);
+  invisible(this)
 }, protected=TRUE)
 
 
 setMethodS3("getNameContentDefaultAttributes", "RspDirective", function(item, known=NULL, doc=NULL, ...) {
-  name <- getAttribute(item, "name");
-  content <- getAttribute(item, "content");
-  default <- getAttribute(item, "default");
-  file <- getAttribute(item, "file");
+  name <- getAttribute(item, "name")
+  content <- getAttribute(item, "content")
+  default <- getAttribute(item, "default")
+  file <- getAttribute(item, "file")
 
   # Was directive given in short format <@<directive> file="<content>">?
   if (is.null(name) && is.null(content) && !is.null(file)) {
-    name <- "file";
-    content <- file;
-    file <- NULL;
+    name <- "file"
+    content <- file
+    file <- NULL
   }
 
   # Was directive given in short format <@<directive> <name>="<content>">?
   if (is.null(name) && is.null(content)) {
-    attrs <- getAttributes(item);
-    names <- setdiff(names(attrs), c("file", "default", known));
+    attrs <- getAttributes(item)
+    names <- setdiff(names(attrs), c("file", "default", known))
     if (length(names) == 0L) {
-      throw(RspPreprocessingException("At least one of attributes 'name' and 'content' must be given", item=item));
+      throw(RspPreprocessingException("At least one of attributes 'name' and 'content' must be given", item=item))
     }
-    name <- names[1L];
-    content <- attrs[[name]];
+    name <- names[1L]
+    content <- attrs[[name]]
   }
 
   # Was directive given with 'file' attribute?
   if (!is.null(file) && !is.null(doc)) {
-    path <- getPath(doc);
+    path <- getPath(doc)
     if (!is.null(path)) {
-      pathname <- file.path(getPath(doc), file);
+      pathname <- file.path(getPath(doc), file)
     } else {
-      pathname <- file;
+      pathname <- file
     }
     # Sanity check
-    stopifnot(!is.null(pathname));
-    content <- .readText(pathname);
+    stop_if_not(!is.null(pathname))
+    content <- .readText(pathname)
   }
 
 
   # Use default?
   if (!is.null(content) && (is.na(content) || content == "NA")) {
-    value <- default;
+    value <- default
   } else {
-    value <- content;
+    value <- content
   }
 
-  list(name=name, value=value, content=content, file=file, default=default);
+  list(name=name, value=value, content=content, file=file, default=default)
 }, protected=TRUE) # getNameContentDefaultAttributes()
 
 
 setMethodS3("asRspString", "RspDirective", function(object, ...) {
-  body <- unclass(object);
-  attrs <- getAttributes(object);
+  body <- unclass(object)
+  attrs <- getAttributes(object)
   if (length(attrs) == 0L) {
-    attrs <- "";
+    attrs <- ""
   } else {
-    attrs <- sprintf('%s="%s"', names(attrs), attrs);
-    attrs <- paste(c("", attrs), collapse=" ");
+    attrs <- sprintf('%s="%s"', names(attrs), attrs)
+    attrs <- paste(c("", attrs), collapse=" ")
   }
 
-  comment <- getComment(object);
+  comment <- getComment(object)
   if (length(comment) == 0L) {
-    comment <- "";
+    comment <- ""
   } else {
-    comment <- sprintf(" #%s", comment);
+    comment <- sprintf(" #%s", comment)
   }
-  suffixSpecs <- attr(object, "suffixSpecs");
+  suffixSpecs <- attr(object, "suffixSpecs")
   if (length(suffixSpecs) == 0L) {
-    suffixSpecs <- "";
+    suffixSpecs <- ""
   }
-  fmtstr <- "<%%@%s%s%s%s%%>";
-  s <- sprintf(fmtstr, body, attrs, comment, suffixSpecs);
-  RspString(s);
+  fmtstr <- "<%%@%s%s%s%s%%>"
+  s <- sprintf(fmtstr, body, attrs, comment, suffixSpecs)
+  RspString(s)
 })
 
 
@@ -183,7 +183,7 @@ setMethodS3("asRspString", "RspDirective", function(object, ...) {
 # @keyword internal
 #*/###########################################################################
 setConstructorS3("RspUnparsedDirective", function(value="unparsed", ...) {
-  extend(RspDirective(value, ...), "RspUnparsedDirective");
+  extend(RspDirective(value, ...), "RspUnparsedDirective")
 })
 
 
@@ -218,59 +218,59 @@ setMethodS3("parseDirective", "RspUnparsedDirective", function(expr, ...) {
   # Local function
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   parseAttributes <- function(rspCode, known=mandatory, mandatory=NULL, ...) {
-    bfr <- rspCode;
+    bfr <- rspCode
 
     # Argument 'known':
-    known <- unique(union(known, mandatory));
+    known <- unique(union(known, mandatory))
 
     # Remove all leading white spaces
-    pos <- regexpr("^[ \t\n\r]+", bfr);
-    len <- attr(pos, "match.length");
-    bfr <- substring(bfr, first=len+1L);
+    pos <- regexpr("^[ \t\n\r]+", bfr)
+    len <- attr(pos, "match.length")
+    bfr <- substring(bfr, first=len+1L)
 
-    attrs <- list();
+    attrs <- list()
     if (nchar(bfr) > 0L) {
       # Add a white space
-      bfr <- paste(" ", bfr, sep="");
+      bfr <- paste(" ", bfr, sep="")
       while (nchar(bfr) > 0L) {
         # Read all (mandatory) white spaces
-        pos <- regexpr("^[ \t\n\r]+", bfr);
+        pos <- regexpr("^[ \t\n\r]+", bfr)
         if (pos == -1L) {
-          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected white space: ", code=sQuote(rspCode)));
+          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected white space: ", code=sQuote(rspCode)))
         }
-        len <- attr(pos, "match.length");
-        bfr <- substring(bfr, first=len+1L);
+        len <- attr(pos, "match.length")
+        bfr <- substring(bfr, first=len+1L)
 
         # Nothing left?
         if (nchar(bfr) == 0L) {
-          break;
+          break
         }
 
         # Is the remaining part a comment?
         if (regexpr("^#", bfr) != -1L) {
           # ...then add it as an (R) attribute to 'attrs'.
-          comment <- gsub("^#", "", bfr);
-          attr(attrs, "comment") <- comment;
+          comment <- gsub("^#", "", bfr)
+          attr(attrs, "comment") <- comment
           # ...and finish.
-          break;
+          break
         }
 
         # Read the attribute name
-        pos <- regexpr("^[abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ_][abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9_]*", bfr);
+        pos <- regexpr("^[abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ_][abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9_]*", bfr)
         if (pos == -1L) {
-          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute name: ", code=sQuote(rspCode)));
+          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute name: ", code=sQuote(rspCode)))
         }
-        len <- attr(pos, "match.length");
-        name <- substring(bfr, first=1L, last=len);
-        bfr <- substring(bfr, first=len+1L);
+        len <- attr(pos, "match.length")
+        name <- substring(bfr, first=1L, last=len)
+        bfr <- substring(bfr, first=len+1L)
 
         # Read the '=' with optional white spaces around it
-        pos <- regexpr("^[ \t\n\r]*=[ \t\n\r]*", bfr);
+        pos <- regexpr("^[ \t\n\r]*=[ \t\n\r]*", bfr)
         if (pos == -1L) {
-          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an equal sign: ", code=sQuote(rspCode)));
+          throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an equal sign: ", code=sQuote(rspCode)))
         }
-        len <- attr(pos, "match.length");
-        bfr <- substring(bfr, first=len+1L);
+        len <- attr(pos, "match.length")
+        bfr <- substring(bfr, first=len+1L)
 
         # Work with a raw buffer
         bfrR <- charToRaw(bfr)
@@ -279,171 +279,171 @@ setMethodS3("parseDirective", "RspUnparsedDirective", function(expr, ...) {
         # (a) Identify the bracket symbols
         lbracketR <- bfrR[1L]
         lbracket <- rawToChar(lbracketR)
-        rbracket <- c("{"="}", "("=")", "["="]", "<"=">")[lbracket];
+        rbracket <- c("{"="}", "("=")", "["="]", "<"=">")[lbracket]
 
         # (b) Single brackets or paired ones?
         if (is.na(rbracket)) {
           # (i) Single, e.g. '...', "...", @...@ etc.
-          bfrR <- bfrR[-1L];
-          wbracket <- 1L;
+          bfrR <- bfrR[-1L]
+          wbracket <- 1L
 
           # Find first non-escape symbol
           pos <- which(bfrR == lbracketR)
 
           # Failed to locate a string enclosed in quotation marks
           if (length(pos) == 0L) {
-            throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute value within quotation marks: ", code=sQuote(rspCode)));
+            throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute value within quotation marks: ", code=sQuote(rspCode)))
           }
 
           # An empty value?
           if (pos[1L] == 1L) {
-            value <- "";
+            value <- ""
           } else {
             # Drop escaped brackets
             keep <- (bfrR[pos-1L] != charToRaw("\\"))
             pos <- pos[keep]
             # Failed to locate a string enclosed in quotation marks
             if (length(pos) == 0L) {
-              throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute value within quotation marks: ", code=sQuote(rspCode)));
+              throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected an attribute value within quotation marks: ", code=sQuote(rspCode)))
             }
-            pos <- pos[1L];
-            bfrR <- bfrR[1:(pos-1)];
-            value <- rawToChar(bfrR);
+            pos <- pos[1L]
+            bfrR <- bfrR[1:(pos-1)]
+            value <- rawToChar(bfrR)
           }
 
           # Record brackets
-          brackets <- c(lbracket, lbracket);
+          brackets <- c(lbracket, lbracket)
 
           # Update buffer
-          bfr <- substring(bfr, first=pos+2L);
+          bfr <- substring(bfr, first=pos+2L)
         } else {
           # (ii) Paired brackets, e.g. {...}, [...], <<...>>
 
           # Width of left bracket, i.e. how many symbols?
           for (wbracket in seq_len(nchar(bfr))) {
-            ch <- substring(bfr, first=wbracket, last=wbracket);
+            ch <- substring(bfr, first=wbracket, last=wbracket)
             if (ch != lbracket) {
-              wbracket <- wbracket - 1L;
-              break;
+              wbracket <- wbracket - 1L
+              break
             }
           }
-          bfr <- substring(bfr, first=wbracket+1L);
+          bfr <- substring(bfr, first=wbracket+1L)
 
           # (c) Identify right bracket symbol (escaped for regexpr)
           rbracket <- c("{"="\\}", "("="\\)", "["="\\]", "<"=">",
-                        "+"="\\+", "."="\\.", "?"="\\?", "|"="\\|")[lbracket];
-          if (is.na(rbracket)) rbracket <- lbracket;
+                        "+"="\\+", "."="\\.", "?"="\\?", "|"="\\|")[lbracket]
+          if (is.na(rbracket)) rbracket <- lbracket
 
           # Right bracket sequence
-          rbrackets <- paste(rep(rbracket, times=wbracket), collapse="");
+          rbrackets <- paste(rep(rbracket, times=wbracket), collapse="")
           # .*? is a non-greedy .* expression
-          pattern <- sprintf("^(.*?)([^\\]?)%s", rbrackets);
-          pos <- regexpr(pattern, bfr);
+          pattern <- sprintf("^(.*?)([^\\]?)%s", rbrackets)
+          pos <- regexpr(pattern, bfr)
 
           # Failed to locate a string enclosed in brackets
           if (pos == -1L) {
-            throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected a attribute value within brackets: ", code=sQuote(rspCode)));
+            throw(Exception("Error when parsing attributes of RSP preprocessing directive. Expected a attribute value within brackets: ", code=sQuote(rspCode)))
           }
 
           # Extract value
-          len <- attr(pos, "match.length");
-          value <- substring(bfr, first=1L, last=len-wbracket);
+          len <- attr(pos, "match.length")
+          value <- substring(bfr, first=1L, last=len-wbracket)
 
           # Record brackets
-          lbrackets <- paste(rep(lbracket, times=wbracket), collapse="");
-          rbrackets <- gsub("\\\\", "\\", rbrackets);
-          brackets <- c(lbrackets, rbrackets);
+          lbrackets <- paste(rep(lbracket, times=wbracket), collapse="")
+          rbrackets <- gsub("\\\\", "\\", rbrackets)
+          brackets <- c(lbrackets, rbrackets)
 
           # Consume buffer
-          bfr <- substring(bfr, first=len+wbracket);
+          bfr <- substring(bfr, first=len+wbracket)
         } # if (is.na(rbracket))
 
         # Set the name of the value
-        names(value) <- name;
+        names(value) <- name
 
         # TODO: Record brackets used
         # ...
 
-        attrs <- c(attrs, value);
+        attrs <- c(attrs, value)
       }
     } # if (nchar(bfr) > 0L)
 
     # Check for duplicated attributes
     if (length(names(attrs)) != length(unique(names(attrs))))
-        throw(Exception("Duplicated attributes in RSP preprocessing directive.", code=sQuote(rspCode)));
+        throw(Exception("Duplicated attributes in RSP preprocessing directive.", code=sQuote(rspCode)))
 
     # Check for unknown attributes
     if (!is.null(known)) {
-      nok <- which(is.na(match(names(attrs), known)));
+      nok <- which(is.na(match(names(attrs), known)))
       if (length(nok) > 0L) {
-        nok <- paste("'", names(attrs)[nok], "'", collapse=", ", sep="");
-        throw(Exception("Unknown attribute(s) in RSP preprocessing directive: ", nok, code=sQuote(rspCode)));
+        nok <- paste("'", names(attrs)[nok], "'", collapse=", ", sep="")
+        throw(Exception("Unknown attribute(s) in RSP preprocessing directive: ", nok, code=sQuote(rspCode)))
       }
     }
 
     # Check for missing mandatory attributes
     if (!is.null(mandatory)) {
-      nok <- which(is.na(match(mandatory, names(attrs))));
+      nok <- which(is.na(match(mandatory, names(attrs))))
       if (length(nok) > 0L) {
-        nok <- paste("'", mandatory[nok], "'", collapse=", ", sep="");
-        throw(Exception("Missing attribute(s) in RSP preprocessing directive: ", nok, code=sQuote(rspCode)));
+        nok <- paste("'", mandatory[nok], "'", collapse=", ", sep="")
+        throw(Exception("Missing attribute(s) in RSP preprocessing directive: ", nok, code=sQuote(rspCode)))
       }
     }
 
     # Return parsed attributes.
-    attrs;
+    attrs
   } # parseAttributes()
 
 
-  body <- expr;
+  body <- expr
 
-  pattern <- "^[ ]*([abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ][abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9]*)([ \t\n\r]+(.*))*";
+  pattern <- "^[ ]*([abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ][abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0-9]*)([ \t\n\r]+(.*))*"
 
   # Sanity check
   if (regexpr(pattern, body) == -1L) {
-    throw("Not an RSP preprocessing directive: ", body);
+    throw("Not an RSP preprocessing directive: ", body)
   }
 
   # <%@foo attr1="bar" attr2="geek"%> => ...
-  directive <- gsub(pattern, "\\1", body);
-  directive <- tolower(directive);
+  directive <- gsub(pattern, "\\1", body)
+  directive <- tolower(directive)
 
   # Parse the attributes
-  attrs <- gsub(pattern, "\\2", body);
-  attrs <- parseAttributes(attrs, known=NULL);
-  comment <- attr(attrs, "comment");
+  attrs <- gsub(pattern, "\\2", body)
+  attrs <- parseAttributes(attrs, known=NULL)
+  comment <- attr(attrs, "comment")
 
   # Infer the class name
-  className <- sprintf("Rsp%sDirective", capitalize(directive));
+  className <- sprintf("Rsp%sDirective", capitalize(directive))
 
   # Get constructor
   clazz <- tryCatch({
-    ns <- getNamespace("R.rsp");
-    Class$forName(className, envir=ns);
+    ns <- getNamespace("R.rsp")
+    Class$forName(className, envir=ns)
   }, error = function(ex) {
-    NULL;
+    NULL
   })
 
   # Instantiate object
   if (!is.null(clazz)) {
-    res <- newInstance(clazz, attrs=attrs, comment=comment);
+    res <- newInstance(clazz, attrs=attrs, comment=comment)
   } else {
-    res <- RspUnknownDirective(directive, attrs=attrs);
+    res <- RspUnknownDirective(directive, attrs=attrs)
   }
 
   # Preserve attributes
-  attr(res, "suffixSpecs") <- attr(expr, "suffixSpecs");
+  attr(res, "suffixSpecs") <- attr(expr, "suffixSpecs")
 
-  res;
+  res
 })
 
 
 setMethodS3("asRspString", "RspUnparsedDirective", function(object, ...) {
-  body <- unclass(object);
-  suffixSpecs <- attr(object, "suffixSpecs");
-  fmtstr <- "<%%@%s%s%%>";
-  s <- sprintf(fmtstr, body, suffixSpecs);
-  RspString(s);
+  body <- unclass(object)
+  suffixSpecs <- attr(object, "suffixSpecs")
+  fmtstr <- "<%%@%s%s%%>"
+  s <- sprintf(fmtstr, body, suffixSpecs)
+  RspString(s)
 })
 
 
@@ -479,11 +479,11 @@ setMethodS3("asRspString", "RspUnparsedDirective", function(object, ...) {
 # @keyword internal
 #*/###########################################################################
 setConstructorS3("RspIncludeDirective", function(value="include", ...) {
-  this <- extend(RspDirective(value, ...), "RspIncludeDirective");
+  this <- extend(RspDirective(value, ...), "RspIncludeDirective")
   if (!missing(value)) {
-    requireAttributes(this, names=c("file", "text"), condition="any");
+    requireAttributes(this, names=c("file", "text"), condition="any")
   }
-  this;
+  this
 })
 
 
@@ -514,7 +514,7 @@ setConstructorS3("RspIncludeDirective", function(value="include", ...) {
 # }
 #*/#########################################################################
 setMethodS3("getFile", "RspIncludeDirective", function(directive, ...) {
-  getAttribute(directive, "file");
+  getAttribute(directive, "file")
 })
 
 #########################################################################/**
@@ -543,7 +543,7 @@ setMethodS3("getFile", "RspIncludeDirective", function(directive, ...) {
 # }
 #*/#########################################################################
 setMethodS3("getContent", "RspIncludeDirective", function(directive, ...) {
-  getAttribute(directive, "content");
+  getAttribute(directive, "content")
 })
 
 
@@ -573,10 +573,10 @@ setMethodS3("getContent", "RspIncludeDirective", function(directive, ...) {
 # }
 #*/#########################################################################
 setMethodS3("getVerbatim", "RspIncludeDirective", function(directive, ...) {
-  res <- getAttribute(directive, "verbatim", default=FALSE);
-  res <- as.logical(res);
-  res <- isTRUE(res);
-  res;
+  res <- getAttribute(directive, "verbatim", default=FALSE)
+  res <- as.logical(res)
+  res <- isTRUE(res)
+  res
 })
 
 
@@ -606,11 +606,11 @@ setMethodS3("getVerbatim", "RspIncludeDirective", function(directive, ...) {
 # }
 #*/#########################################################################
 setMethodS3("getWrap", "RspIncludeDirective", function(directive, ...) {
-  res <- getAttribute(directive, "wrap");
+  res <- getAttribute(directive, "wrap")
   if (!is.null(res)) {
-    res <- as.integer(res);
+    res <- as.integer(res)
   }
-  res;
+  res
 })
 
 
@@ -648,13 +648,13 @@ setMethodS3("getWrap", "RspIncludeDirective", function(directive, ...) {
 # @keyword internal
 #*/###########################################################################
 setConstructorS3("RspEvalDirective", function(value="eval", ...) {
-  this <- extend(RspDirective(value, ...), "RspEvalDirective");
+  this <- extend(RspDirective(value, ...), "RspEvalDirective")
   if (!missing(value)) {
-    requireAttributes(this, names=c("file", "text"), condition="any");
-    lang <- getAttribute(this, default="R");
-    this <- setAttribute(this, "language", lang);
+    requireAttributes(this, names=c("file", "text"), condition="any")
+    lang <- getAttribute(this, default="R")
+    this <- setAttribute(this, "language", lang)
   }
-  this;
+  this
 })
 
 
@@ -684,7 +684,7 @@ setConstructorS3("RspEvalDirective", function(value="eval", ...) {
 # }
 #*/#########################################################################
 setMethodS3("getFile", "RspEvalDirective", function(directive, ...) {
-  getAttribute(directive, "file");
+  getAttribute(directive, "file")
 })
 
 
@@ -714,7 +714,7 @@ setMethodS3("getFile", "RspEvalDirective", function(directive, ...) {
 # }
 #*/#########################################################################
 setMethodS3("getContent", "RspEvalDirective", function(directive, ...) {
-  getAttribute(directive, "content");
+  getAttribute(directive, "content")
 })
 
 
@@ -777,13 +777,13 @@ setConstructorS3("RspPageDirective", function(value="page", ...) {
 # }
 #*/#########################################################################
 setMethodS3("getType", "RspPageDirective", function(directive, default=NA, as=c("text", "IMT"), ...) {
-  as <- match.arg(as);
-  res <- getAttribute(directive, "type", default=as.character(default));
-  res <- tolower(res);
+  as <- match.arg(as)
+  res <- getAttribute(directive, "type", default=as.character(default))
+  res <- tolower(res)
   if (as == "IMT" && !is.na(res)) {
-    res <- parseInternetMediaType(res);
+    res <- parseInternetMediaType(res)
   }
-  res;
+  res
 })
 
 
@@ -849,5 +849,5 @@ setConstructorS3("RspUnknownDirective", function(value="unknown", ...) {
 # @keyword internal
 #*/###########################################################################
 setConstructorS3("RspErrorDirective", function(value="error", ...) {
-  extend(RspDirective(value, ...), "RspErrorDirective");
+  extend(RspDirective(value, ...), "RspErrorDirective")
 })
