@@ -38,57 +38,57 @@ setMethodS3("compileSweave", "default", function(filename, path=NULL, ..., outPa
   # Validate arguments
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Arguments 'filename' & 'path':
-  pathname <- if (is.null(path)) filename else file.path(path, filename);
+  pathname <- if (is.null(path)) filename else file.path(path, filename)
   if (!isUrl(pathname)) {
-    pathname <- Arguments$getReadablePathname(pathname);
+    pathname <- Arguments$getReadablePathname(pathname)
   }
 
   # Arguments 'outPath':
-  outPath <- Arguments$getWritablePath(outPath);
-  if (is.null(outPath)) outPath <- ".";
+  outPath <- Arguments$getWritablePath(outPath)
+  if (is.null(outPath)) outPath <- "."
 
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
   if (verbose) {
-    pushState(verbose);
-    on.exit(popState(verbose));
+    pushState(verbose)
+    on.exit(popState(verbose))
   }
 
-  verbose && enter(verbose, "Compiling Sweave document");
+  verbose && enter(verbose, "Compiling Sweave document")
   # Download URL?
   if (isUrl(pathname)) {
-    verbose && enter(verbose, "Downloading URL");
-    url <- pathname;
-    verbose && cat(verbose, "URL: ", url);
-    pathname <- downloadFile(url, verbose=less(verbose,50));
-    verbose && cat(verbose, "Local file: ", pathname);
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Downloading URL")
+    url <- pathname
+    verbose && cat(verbose, "URL: ", url)
+    pathname <- downloadFile(url, verbose=less(verbose,50))
+    verbose && cat(verbose, "Local file: ", pathname)
+    verbose && exit(verbose)
   }
 
-  pathname <- getAbsolutePath(pathname);
-  verbose && cat(verbose, "Sweave pathname (absolute): ", pathname);
-  verbose && printf(verbose, "Input file size: %g bytes\n", file.info(pathname)$size);
-  verbose && cat(verbose, "Output and working directory: ", outPath);
+  pathname <- getAbsolutePath(pathname)
+  verbose && cat(verbose, "Sweave pathname (absolute): ", pathname)
+  verbose && printf(verbose, "Input file size: %g bytes\n", file.info(pathname)$size)
+  verbose && cat(verbose, "Output and working directory: ", outPath)
 
-  opwd <- ".";
-  on.exit(setwd(opwd), add=TRUE);
+  opwd <- "."
+  on.exit(setwd(opwd), add=TRUE)
   if (!is.null(outPath)) {
-    opwd <- setwd(outPath);
+    opwd <- setwd(outPath)
   }
 
-  pathname2 <- Sweave(pathname);
-  pathname2 <- getAbsolutePath(pathname2);
-  setwd(opwd); opwd <- ".";
+  pathname2 <- Sweave(pathname)
+  pathname2 <- getAbsolutePath(pathname2)
+  setwd(opwd); opwd <- "."
 
-  res <- RspFileProduct(pathname2);
-  verbose && print(verbose, res);
+  res <- RspFileProduct(pathname2)
+  verbose && print(verbose, res)
 
   # Postprocess?
   if (postprocess) {
-    res <- process(res, outPath=outPath, recursive=TRUE, verbose=verbose);
+    res <- process(res, outPath=outPath, recursive=TRUE, verbose=verbose)
   }
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 
-  res;
+  res
 }) # compileSweave()
